@@ -15,7 +15,7 @@ boottest.lm <- function(object,
                         na_omit = TRUE, 
                         nthreads = getBoottest_nthreads(), 
                         ...) {
-
+  
   #' Fast wild cluster bootstrap inference for object of class lm
   #' 
   #' `boottest.lm` is a S3 method that allows for fast wild cluster 
@@ -23,36 +23,48 @@ boottest.lm <- function(object,
   #' the fast wild bootstrap algorithm developed in Roodman et al., 2019.
   #' 
   #' @param object An object of class lm
-  #' @param clustid A vector with the clusters
-  #' @param param Character vector of length one. The name of the regression
+  #' @param clustid A character vector containing the names of the cluster variables
+  #' @param param A character vector of length one. The name of the regression
   #'        coefficient for which the hypothesis is to be tested
-  #' @param B Integer. number of bootstrap iterations
-  #' @param bootcluster A character vector. Sets the cluster used in the 
-  #'        bootstrap dgp. Chooses the largest cluster by default
-  #' @param sign_level A numeric between 0 and 1. E.g. sign_level = 0.05 
+  #' @param B Integer. The number of bootstrap iterations. When the number of clusters is low, 
+  #'        increasing B adds little additional runtime. 
+  #' @param bootcluster A character vector. Specifies the bootstrap clustering variable or variables. If more
+  #'        than one variable is specified, then bootstrapping is clustered by the intersections of
+  #'        clustering implied by the listed variables. To mimic the behavior of stata's boottest command, 
+  #'        the default is to cluster by the intersection of all the variables specified via the `clustid` argument, 
+  #'        even though that is not necessarily recommended (see the paper by Roodman et al cited below, section 4.2). 
+  #'        Other options include "min", where bootstrapping is clustered by the cluster variable with the fewest clusters.
+  #' @param sign_level A numeric between 0 and 1 which sets the significance level 
+  #'        of the inference procedure. E.g. sign_level = 0.05 
   #'        returns 0.95% confidence intervals. By default, sign_level = 0.05.
   #' @param conf_int A logical vector. If TRUE, boottest computes confidence 
   #'        intervals by p-value inversion. If FALSE, only the p-value is returned.
-  #' @param seed An integer. Allows the user to set a random seed
+  #' @param seed An integer. Allows the user to set a random seed. If NULL, `boottest()` sets an
+  #'        internal seed. Hence by default, calling `boottest()` multiple times on the same object will produce 
+  #'        the same test statistics.
   #' @param beta0 A numeric. Shifts the null hypothesis 
   #'        H0: param = beta0 vs H1: param != beta0
   #' @param type character or function. The character string specifies the type
   #'        of boostrap to use: One of "rademacher", "mammen", "norm"
   #'        and "webb". Alternatively, type can be a function(n) for drawing 
-  #'        wild bootstrap factors. "rademacher" by default.
+  #'        wild bootstrap factors. "rademacher" by default.  
+  #'        For the Rademacher and Mammen distribution, if the number of replications B exceeds 
+  #'        the number of possible draw ombinations, 2^(#number of clusters), then `boottest()` 
+  #'        will use each possible combination once (enumeration).
   #' @param impose_null Logical. Controls if the null hypothesis is imposed on
   #'        the bootstrap dgp or not. Null imposed `(WCR)` by default.
   #'        If FALSE, the null is not imposed `(WCU)`
   #' @param p_val_type Character vector of length 1. Type of p-value. 
-  #'        By default "two-tailed". Other options: "equal-tailed"
+  #'        By default "two-tailed". 
   #' @param tol Numeric vector of length 1. The desired accuracy 
-  #'        (convergence tolerance) for confidence interval inversion.
+  #'        (convergence tolerance) used in the root finding procedure to find the confidence interval.
   #'        1e-6 by default.
-  #' @param maxiter Integer. Maximum number of iterations for confidence 
-  #'        interval inversion. 10 by default.
+  #' @param maxiter Integer. Maximum number of iterations used in the root finding procedure to find the confidence interval.
+  #'        10 by default.
   #' @param na_omit Logical. If TRUE, `boottest()` omits rows with missing 
-  #'        variables that are added to the model via the `clustid` argument 
-  #'        in `boottest()`
+  #'        variables in the cluster variable that have not previously been deleted
+  #'        when fitting the regression object (e.g. if the cluster variable was not used 
+  #'        when fitting the regression model).
   #' @param nthreads The number of threads. Can be: a) an integer lower than, 
   #'                 or equal to, the maximum number of threads; b) 0: meaning 
   #'                 all available threads will be used; c) a number strictly
@@ -127,7 +139,7 @@ boottest.lm <- function(object,
   #'                   beta0 = 2)
   #' summary(boot1)
   #' plot(boot1)
-
+  
   call <- match.call()
   dreamerr::validate_dots(stop = TRUE)
   
@@ -145,6 +157,10 @@ boottest.lm <- function(object,
   # check appropriateness of nthreads
   nthreads <- check_set_nthreads(nthreads)
   
+  if(is.null(seed)){
+    seed <- 1
+  }
+  
   if(maxiter < 1){
     stop("The function argument maxiter needs to be larger than 1.", 
          call. = FALSE)
@@ -154,7 +170,7 @@ boottest.lm <- function(object,
     stop("The function argument tol needs to be positive.", 
          call. = FALSE)
   }
-
+  
   if(!(p_val_type %in% c("two-tailed", "equal-tailed"))){
     stop("The function argument p_val_type must be either two-tailed or 
          equal-tailed.", 
@@ -166,40 +182,40 @@ boottest.lm <- function(object,
           iterations needs to be 100 or higher in order to guarantee that the 
           root finding procudure used to find the confidence set 
           works properly.",
-      call. = FALSE
+         call. = FALSE
     )
   }
   if (!is.null(sign_level) & (sign_level <= 0 || sign_level >= 1)) {
     stop("The function argument sign_level is outside of the unit interval
          (0, 1). Please specify sign_level so that it is within the
          unit interval.",
-      call. = FALSE
+         call. = FALSE
     )
   }
-
+  
   if (is.null(sign_level)) {
     sign_level <- 0.05
   }
-
+  
   if (!(param %in% c(names(coef(object))))) {
     stop(paste("The parameter", param, "is not included in the estimated model.
                Maybe you are trying to test for an interaction parameter? 
                To see all model parameter names, run names(coef(model))."))
   }
-
+  
   if (is.null(beta0)) {
     beta0 <- 0
   }
-
-
+  
+  
   if (((1 - sign_level) * (B + 1)) %% 1 != 0) {
     message(paste("Note: The bootstrap usually performs best when the
                   confidence level (here,", 1 - sign_level, "%) 
                   times the number of replications plus 1
                   (", B, "+ 1 = ", B + 1, ") is an integer."))
   }
-
-
+  
+  
   # throw error if specific function arguments are used in lm() call
   call_object <- names(object$call)[names(object$call) != ""]
   banned_fun_args <- c("contrasts", "subset", "offset", "x", "y")
@@ -213,7 +229,7 @@ boottest.lm <- function(object,
     call. = FALSE
     )
   }
-
+  
   # preprocess data: X, Y, weights, fixed effects
   preprocess <- preprocess2(object = object,
                             cluster = clustid,
@@ -221,43 +237,50 @@ boottest.lm <- function(object,
                             param = param,
                             bootcluster = bootcluster, 
                             na_omit = na_omit)
-
-
+  
+  
   clustid_dims <- preprocess$clustid_dims
   point_estimate <- object$coefficients[param]
-
+  
   clustid_fml <- as.formula(paste("~", paste(clustid, collapse = "+")))
-
-  N_G_2 <- 2^length(unique(preprocess$bootcluster[, 1]))
+  
+  # number of clusters used in bootstrap - always derived from bootcluster
+  N_G <- length(unique(preprocess$bootcluster[, 1]))
+  N_G_2 <- 2^N_G
   if (type %in% c("rademacher", "mammen") & N_G_2 < B) {
-    warning(paste("There are only", N_G_2, "unique draws from the rademacher 
-                  distribution for",
-                  length(unique(preprocess$bootcluster[, 1])), 
-                  "clusters. Therefore, 
-                  B = ", N_G_2, " with full enumeration. Consider using webb weights instead."),
-      call. = FALSE, 
-      noBreaks. = TRUE
+    warning(paste("There are only", N_G_2, "unique draws from the rademacher distribution for", length(unique(preprocess$bootcluster[, 1])), "clusters. Therefore, B = ", N_G_2, " with full enumeration. Consider using webb weights instead."),
+            call. = FALSE, 
+            noBreaks. = TRUE
+    )
+    warning(paste("Further, note that under full enumeration and with B =", N_G_2, "bootstrap draws, only 2^(#clusters - 1) = ", 2^(N_G - 1), " distinct t-statistics and p-values can be computed. For a more thorough discussion, see Webb `Reworking wild bootstrap based inference for clustered errors` (2013)."),
+            call. = FALSE, 
+            noBreaks. = TRUE
     )
     B <- N_G_2
+    full_enumeration <- TRUE
+  } else{
+    full_enumeration <- FALSE
   }
-
+  
+  
   # conduct inference: calculate p-value
   res <- boot_algo2(preprocess,
-    boot_iter = B,
-    point_estimate = point_estimate,
-    impose_null = impose_null,
-    beta0 = beta0,
-    sign_level = sign_level,
-    param = param,
-    seed = seed,
-    p_val_type = p_val_type, 
-    nthreads = nthreads, 
-    type = type
+                    boot_iter = B,
+                    point_estimate = point_estimate,
+                    impose_null = impose_null,
+                    beta0 = beta0,
+                    sign_level = sign_level,
+                    param = param,
+                    seed = seed,
+                    p_val_type = p_val_type, 
+                    nthreads = nthreads, 
+                    type = type, 
+                    full_enumeration = full_enumeration
   )
-
+  
   # compute confidence sets
-
-
+  
+  
   if (is.null(conf_int) || conf_int == TRUE) {
     
     # guess for standard errors
@@ -271,7 +294,7 @@ boottest.lm <- function(object,
     # if (is.na(se_guess)) {
     #   se_guess <- object$se[param]
     # }
-
+    
     res_p_val <- invert_p_val2(
       object = res,
       boot_iter = B,
@@ -292,7 +315,7 @@ boottest.lm <- function(object,
       test_vals = NA
     )
   }
-
+  
   res_final <- list(
     point_estimate = point_estimate,
     p_val = res[["p_val"]],
@@ -312,9 +335,9 @@ boottest.lm <- function(object,
     type = type,
     impose_null = impose_null
   )
-
-
+  
+  
   class(res_final) <- "boottest"
-
+  
   invisible(res_final)
-}
+}
\ No newline at end of file
