@@ -8,8 +8,6 @@ knitr::opts_chunk$set(
 library(fwildclusterboot)
 
 ## ---- error = FALSE, warning = FALSE, message = FALSE-------------------------
-library(fixest)
-library(lfe)
 
 # load data set voters included in fwildclusterboot
 data(voters)
@@ -17,12 +15,6 @@ data(voters)
 # estimate the regression model via lm
 lm_fit <- lm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration , data = voters)
 
-# estimate the regression model via feols
-feols_fit <- feols(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration , data = voters)
-
-# estimate the regression model via felm
-felm_fit <- felm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration , data = voters)
-
 # model with interaction
 lm_fit_interact <- lm(proposition_vote ~ treatment + ideology1 + log_income:Q1_immigration , data = voters)
 
@@ -30,25 +22,23 @@ lm_fit_interact <- lm(proposition_vote ~ treatment + ideology1 + log_income:Q1_i
 ## -----------------------------------------------------------------------------
 # boottest on an object of type lm
 boot_lm <- boottest(lm_fit, clustid = "group_id1", param = "treatment", B = 9999)
-# boottest on an object of type fixest
-boot_feols <- boottest(feols_fit, clustid = "group_id1", param = "treatment", B = 9999)
-# boottest on an object of type felm
-boot_felm <- boottest(felm_fit, clustid = "group_id1", param = "treatment", B = 9999)
 
 ## -----------------------------------------------------------------------------
-names(coef(lm_fit_interact))
+#names(coef(lm_fit_interact))
 boot_lm_interact <- boottest(lm_fit_interact, clustid = "group_id1", param = "log_income:Q1_immigration1", B = 9999)
 
 ## -----------------------------------------------------------------------------
-library(modelsummary)
-
 # fwildclusterboot's internal summary() method
 summary(boot_lm)
 
-# summary via the modelsummary package
-msummary(list(boot_lm, boot_feols), 
-          estimate = "{estimate} ({p.value})", 
-         statistic = "[{conf.low}, {conf.high}]")
+if(requireNamespace("modelsummary")){
+  # summary via the modelsummary package
+  library(modelsummary)
+  msummary(list(boot_lm, boot_lm_interact), 
+            estimate = "{estimate} ({p.value})", 
+           statistic = "[{conf.low}, {conf.high}]")  
+}
+
 
 
 ## -----------------------------------------------------------------------------
@@ -70,10 +60,12 @@ boot_lm_webb <- boottest(lm_fit,
                     B = 999,
                     type = "webb")
 
-msummary(list(boot_lm_rade, boot_lm_webb), 
+if(requireNamespace("modelsummary")){
+  library(modelsummary)
+  msummary(list(boot_lm_rade, boot_lm_webb), 
           estimate = "{estimate} ({p.value})", 
          statistic = "[{conf.low}, {conf.high}]")
-
+}
 
 ## -----------------------------------------------------------------------------
 boot_lm_5 <- boottest(lm_fit, 
@@ -85,9 +77,12 @@ boot_lm_10 <- boottest(lm_fit,
                     param = "treatment", B = 9999, 
                     sign_level = 0.10)
 
-msummary(list(boot_lm_5, boot_lm_10), 
+if(requireNamespace("modelsummary")){
+  library(modelsummary)
+  msummary(list(boot_lm_5, boot_lm_10), 
           estimate = "{estimate} ({p.value})", 
          statistic = "[{conf.low}, {conf.high}]")
+}
 
 ## -----------------------------------------------------------------------------
 boot_lm1 <- boottest(lm_fit, 
@@ -102,28 +97,25 @@ boot_lm2 <- boottest(lm_fit,
                     B = 9999, 
                     bootcluster = "group_id1")
 
-msummary(list(boot_lm1, boot_lm2), 
+if(requireNamespace("modelsummary")){
+  library(modelsummary)
+  msummary(list(boot_lm1, boot_lm2), 
           estimate = "{estimate} ({p.value})", 
          statistic = "[{conf.low}, {conf.high}]")
+}
 
 ## -----------------------------------------------------------------------------
-# estimate the regression model via feols
-feols_fit <- feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration , data = voters)
 
-# estimate the regression model via felm
-felm_fit <- felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration , data = voters)
-
-boot_feols <- boottest(feols_fit, 
-                       clustid = "group_id1", 
-                       param = "treatment", 
-                       B = 9999, 
-                       fe = "Q1_immigration")
-
-boot_felm <- boottest(felm_fit, 
-                      clustid = "group_id1",
-                      param = "treatment", 
-                      B = 9999, 
-                      fe = "Q1_immigration")
+if(requireNamespace("fixest")){
+  # estimate the regression model via feols
+  library(fixest)
+  feols_fit <- feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration , data = voters)
+  boot_feols <- boottest(feols_fit, 
+                         clustid = "group_id1", 
+                         param = "treatment", 
+                         B = 9999, 
+                         fe = "Q1_immigration")
+}
 
 
 ## -----------------------------------------------------------------------------
@@ -143,25 +135,27 @@ boot_2var <- boottest(lm_fit,
                     B = 9999, 
                     bootcluster = c("group_id1", "Q1_immigration"))
 
-msummary(model = list(boot_min, boot_2var), 
+if(requireNamespace("modelsummary")){
+  library(modelsummary)
+  msummary(model = list(boot_min, boot_2var), 
          estimate = "{estimate} ({p.value})", 
          statistic = "[{conf.low}, {conf.high}]")
-
+}
 
 
 
 ## -----------------------------------------------------------------------------
 # regression with weights / WLS
-feols_fit <- feols(proposition_vote ~ treatment + ideology1 + log_income, weights = voters$weights, data = voters)
+lm_w_fit <- lm(proposition_vote ~ treatment + ideology1 + log_income, weights = voters$weights, data = voters)
 
-boot_feols <- boottest(feols_fit, 
+boot_w_lm <- boottest(lm_w_fit, 
                        clustid = "group_id1", 
                        param = "treatment", 
                        B = 9999)
 
 
 ## ---- eval = FALSE------------------------------------------------------------
-#  boot_feols <- boottest(feols_fit,
+#  boot_lm <- boottest(lm_fit,
 #                         clustid = "group_id1",
 #                         param = "treatment",
 #                         B = 9999,
