@@ -18,9 +18,7 @@
 #            - in total: 10 boottest objects created
 # ------------------------------------------------------------------ # 
 
-library(fwildclusterboot)
-library(lfe)
-library(fixest)
+# library(fwildclusterboot)
 # ---------------------------------------------------------------------------------------------- # 
 # Part 1: one cluster variable
 # ---------------------------------------------------------------------------------------------- # 
@@ -31,17 +29,17 @@ library(fixest)
 lm_fit <- lm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration , 
              weights = 1:10000/ 10000, 
              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration, 
+feols_fit <- feols(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration, 
                            weights = 1:10000/ 10000, 
                            data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration,  
+felm_fit <- felm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration,  
                       weights = 1:10000/ 10000, 
                       data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit_c <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration, 
+feols_fit_c <- feols(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration, 
                              weights = 1:10000/ 10000, 
                              cluster = "group_id1",
                              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit_c <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration | 0 | 0 | group_id1,
+felm_fit_c <- felm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration | 0 | 0 | group_id1,
                         weights = 1:10000/ 10000, 
                         data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
 
@@ -88,14 +86,14 @@ expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
 
 lm_fit <- lm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration ,  weights = 1:10000/ 10000, 
              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
+feols_fit <- feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
                            data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
+felm_fit <- felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
                       data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit_c <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
+feols_fit_c <- feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
                              cluster = "group_id1",
                              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit_c <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration  | 0 | group_id1, weights = 1:10000/ 10000, 
+felm_fit_c <- felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration  | 0 | group_id1, weights = 1:10000/ 10000, 
                         data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
 
 boot_lm <-  suppressWarnings(boottest(object = lm_fit, clustid =  "group_id1", B = 999, seed = 911, param = "treatment", conf_int = TRUE))
@@ -164,14 +162,14 @@ expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
 
 lm_fit <- lm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration + Q2_defense, weights = 1:10000/ 10000, 
              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
+feols_fit <- feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
                            data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
+felm_fit <- felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
                       data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit_c <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
+feols_fit_c <- feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
                              cluster = "group_id1",
                              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit_c <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense | 0 | group_id1, weights = 1:10000/ 10000, 
+felm_fit_c <- felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense | 0 | group_id1, weights = 1:10000/ 10000, 
                         data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
 
 boot_lm <-  suppressWarnings(boottest(object = lm_fit, clustid =  "group_id1", B = 999, seed = 911, param = "treatment", conf_int = TRUE))
@@ -245,14 +243,14 @@ expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
 
 lm_fit <- lm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration ,  weights = 1:10000/ 10000, 
              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration,  weights = 1:10000/ 10000, 
+feols_fit <- feols(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration,  weights = 1:10000/ 10000, 
                            data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration,  weights = 1:10000/ 10000, 
+felm_fit <- felm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration,  weights = 1:10000/ 10000, 
                       data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit_c <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration,  weights = 1:10000/ 10000, 
+feols_fit_c <- feols(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration,  weights = 1:10000/ 10000, 
                              cluster = "group_id1",
                              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit_c <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration | 0 | 0 | group_id1, weights = 1:10000/ 10000, 
+felm_fit_c <- felm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration | 0 | 0 | group_id1, weights = 1:10000/ 10000, 
                         data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
 
 boot_lm <-  suppressWarnings(boottest(object = lm_fit, clustid = c("group_id1", "group_id2"), B = 999, seed = 911, param = "treatment", conf_int = TRUE))
@@ -297,14 +295,14 @@ expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
 
 lm_fit <- lm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration ,  weights = 1:10000/ 10000, 
              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
+feols_fit <- feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
                            data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
+felm_fit <- felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
                       data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit_c <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
+feols_fit_c <- feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration,  weights = 1:10000/ 10000, 
                              cluster = "group_id1",
                              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit_c <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration  | 0 | group_id1, weights = 1:10000/ 10000, 
+felm_fit_c <- felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration  | 0 | group_id1, weights = 1:10000/ 10000, 
                         data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
 
 boot_lm <-  suppressWarnings(boottest(object = lm_fit, clustid = c("group_id1", "group_id2"), B = 999, seed = 911, param = "treatment", conf_int = TRUE))
@@ -374,14 +372,14 @@ expect_equivalent(boot_felm_c$conf_int, boot_lm$conf_int, tolerance = 0.1)
 
 lm_fit <- lm(proposition_vote ~ treatment + ideology1 + log_income + Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
+feols_fit <- feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
                            data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
+felm_fit <- felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
                       data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-feols_fit_c <- fixest::feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
+feols_fit_c <- feols(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense,  weights = 1:10000/ 10000, 
                              cluster = "group_id1",
                              data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
-felm_fit_c <- lfe::felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense | 0 | group_id1, weights = 1:10000/ 10000, 
+felm_fit_c <- felm(proposition_vote ~ treatment + ideology1 + log_income | Q1_immigration + Q2_defense | 0 | group_id1, weights = 1:10000/ 10000, 
                         data = fwildclusterboot:::create_data(N = 10000, N_G1 = 20, icc1 = 0.01, N_G2 = 10, icc2 = 0.01, numb_fe1 = 10, numb_fe2 = 10, seed = 1234))
 
 boot_lm <-  suppressWarnings(boottest(object = lm_fit, clustid = c("group_id1", "group_id2"), B = 999, seed = 911, param = "treatment", conf_int = TRUE))
